<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>CategoryDialog</name>
    <message>
        <location filename="../../category_dialog.ui" line="14"/>
        <source>Choose Category</source>
        <translation>Scegli categoria</translation>
    </message>
    <message>
        <location filename="../../category_dialog.ui" line="26"/>
        <source>&amp;Category</source>
        <translation>&amp;Categoria</translation>
    </message>
</context>
<context>
    <name>ConverterWindow</name>
    <message>
        <location filename="../../converter_window.ui" line="14"/>
        <source>Convert Units</source>
        <translation>Convertire Unità</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="22"/>
        <source>Amo&amp;unt</source>
        <translation>Q&amp;uantità</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="79"/>
        <source>kg/l</source>
        <translation>kg/l</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="86"/>
        <source>Con&amp;verted</source>
        <translation>Con&amp;vertito</translation>
    </message>
    <message>
        <location filename="../../converter_window.ui" line="102"/>
        <source>?</source>
        <translation>?</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="104"/>
        <source>rolled oats</source>
        <translation>fiocchi d&apos;avena</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="105"/>
        <source>bread crumbs</source>
        <translation>pangrattato</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="106"/>
        <source>desiccated coconut</source>
        <translation>cocco essiccato</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="107"/>
        <source>cornflour</source>
        <translation>maizena</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="108"/>
        <source>cocoa</source>
        <translation>cacao</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="109"/>
        <source>ground almonds</source>
        <translation>mandorle tritate</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="110"/>
        <source>shredded suet</source>
        <translation>sego tritato</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="111"/>
        <source>sugar</source>
        <translation>zucchero</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="112"/>
        <source>rice</source>
        <translation>riso</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="113"/>
        <source>haricots</source>
        <translation>fagioli</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="114"/>
        <source>lentils</source>
        <translation>lenticchie</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="115"/>
        <source>barley</source>
        <translation>orzo</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="116"/>
        <source>peas</source>
        <translation>piselli</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="117"/>
        <source>sultana</source>
        <translation>uva sultanina</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="118"/>
        <source>tapioca</source>
        <translation>tapioca</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="119"/>
        <source>ground rice</source>
        <translation>riso macinato</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="120"/>
        <source>currants</source>
        <translation>ribes</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="121"/>
        <source>semolina</source>
        <translation>semolino</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="122"/>
        <source>raisins</source>
        <translation>uvetta</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="123"/>
        <source>custard powder</source>
        <translation>preparato per crema pasticcera</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="124"/>
        <source>flour</source>
        <translation>farina</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="125"/>
        <source>milk</source>
        <translation>latte</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="126"/>
        <source>icing sugar</source>
        <translation>zucchero a velo</translation>
    </message>
    <message>
        <location filename="../../converter_window.cc" line="127"/>
        <source>Custom</source>
        <translation>Personalizzato</translation>
    </message>
</context>
<context>
    <name>EditDialog</name>
    <message>
        <location filename="../../edit_dialog.ui" line="14"/>
        <source>Edit Recipe</source>
        <translation>Modifica ricetta</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="28"/>
        <source>&amp;General</source>
        <translation>&amp;Generale</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="36"/>
        <location filename="../../edit_dialog.ui" line="570"/>
        <source>&amp;Title:</source>
        <translation>&amp;Titolo:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="49"/>
        <location filename="../../edit_dialog.ui" line="717"/>
        <source>title</source>
        <translation>titolo</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="56"/>
        <source>&amp;Categories:</source>
        <translation>&amp;Categorie:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="66"/>
        <source>category1, category2, ...</source>
        <translation>categoria1, categoria2, ...</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="73"/>
        <source>&amp;Yield:</source>
        <translation>&amp;Resa:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="98"/>
        <source>servings</source>
        <translation>porzioni</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="123"/>
        <source>&amp;Ingredients</source>
        <translation>&amp;Ingredienti</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="146"/>
        <source>Add &amp;Group</source>
        <translation>Aggiungi &amp;Gruppo</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="153"/>
        <source>Add &amp;Ingredient</source>
        <translation>Aggiungi &amp;Ingrediente</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="160"/>
        <location filename="../../edit_dialog.ui" line="654"/>
        <source>&amp;Remove</source>
        <translation>&amp;Rimuovi</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="167"/>
        <location filename="../../edit_dialog.ui" line="661"/>
        <source>&amp;Up</source>
        <translation>&amp;Sopra</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="178"/>
        <location filename="../../edit_dialog.ui" line="672"/>
        <source>&amp;Down</source>
        <translation>&amp;Giù</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="189"/>
        <source>U&amp;nit Converter</source>
        <translation>Co&amp;nvertire Unità</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="220"/>
        <source>I&amp;ngredient</source>
        <translation>Ingredie&amp;nte</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="226"/>
        <source>A&amp;mount:</source>
        <translation>&amp;Quantità:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="239"/>
        <source>fraction</source>
        <translation>frazione</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="244"/>
        <source>float</source>
        <translation>decimale</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="284"/>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="301"/>
        <source>/</source>
        <translation>/</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="359"/>
        <source>Uni&amp;t:</source>
        <translation>Uni&amp;tà:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="370"/>
        <source>per serving</source>
        <translation>per porzione</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="375"/>
        <source>small</source>
        <translation>piccolo</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="380"/>
        <source>medium</source>
        <translation>medio</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="385"/>
        <source>large</source>
        <translation>grande</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="390"/>
        <source>can</source>
        <translation>lattina</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="395"/>
        <source>package</source>
        <translation>confezione</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="400"/>
        <source>pinch</source>
        <translation>pizzico</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="405"/>
        <source>drop</source>
        <translation>goccia</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="410"/>
        <source>dash</source>
        <translation>goccio</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="415"/>
        <source>carton</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="420"/>
        <source>bunch</source>
        <translation>grappolo</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="425"/>
        <source>slice</source>
        <translation>fetta</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="430"/>
        <source>each</source>
        <translation>cadauno</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="435"/>
        <source>teaspoon</source>
        <translation>cucchiaino</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="440"/>
        <source>tablespoon</source>
        <translation>cucchiaio</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="445"/>
        <source>fluid ounce</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="450"/>
        <source>cup</source>
        <translation>tazza</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="455"/>
        <source>pint</source>
        <translation>pinta</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="460"/>
        <source>quart</source>
        <translation>quarto</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="465"/>
        <source>gallon</source>
        <translation>gallone</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="470"/>
        <source>ounce</source>
        <translation>oncia</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="475"/>
        <source>pound</source>
        <translation>libbra</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="480"/>
        <source>milliliter</source>
        <translation>millilitro</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="485"/>
        <source>cubic cm</source>
        <translation>cm cubi</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="490"/>
        <source>centiliter</source>
        <translation>centilitro</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="495"/>
        <source>deciliter</source>
        <translation>decilitro</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="500"/>
        <source>liter</source>
        <translation>litro</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="505"/>
        <source>milligram</source>
        <translation>milligrammo</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="510"/>
        <source>centigram</source>
        <translation>centigrammo</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="515"/>
        <source>decigram</source>
        <translation>decigrammo</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="520"/>
        <source>gram</source>
        <translation>grammo</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="525"/>
        <source>kilogram</source>
        <translation>chilogrammo</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="538"/>
        <source>Na&amp;me:</source>
        <translation>No&amp;me:</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="548"/>
        <location filename="../../edit_dialog.cc" line="220"/>
        <source>ingredient</source>
        <translation>ingrediente</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="562"/>
        <source>Ingredient &amp;Section</source>
        <translation>Ingrediente &amp;Sezione</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="609"/>
        <source>Select section or ingredient</source>
        <translation>Seleziona la sezione o l&apos;ingrediente</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="624"/>
        <source>In&amp;structions</source>
        <translation>I&amp;struzioni</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="647"/>
        <source>&amp;Add Group</source>
        <translation>&amp;Aggiungi Sezione</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="693"/>
        <source>Instruction</source>
        <translation>Istruzione</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="701"/>
        <source>&amp;Title</source>
        <translation>&amp;Titolo</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="755"/>
        <source>&amp;Ok</source>
        <translation>&amp;Ok</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.ui" line="765"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <location filename="../../edit_dialog.cc" line="242"/>
        <source>Title</source>
        <translation>Titolo</translation>
    </message>
</context>
<context>
    <name>ExportDialog</name>
    <message>
        <location filename="../../export_dialog.ui" line="14"/>
        <source>Export MealMaster Recipes</source>
        <translation>Esporta ricette di MealMaster</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="26"/>
        <source>En&amp;coding</source>
        <translation>&amp;Codificando</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="46"/>
        <source>ISO-8859-1</source>
        <translation>ISO-8859-1</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="51"/>
        <source>ISO-8859-15</source>
        <translation>ISO-8859-15</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="56"/>
        <source>CP850</source>
        <translation>CP850</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="61"/>
        <source>UTF-8</source>
        <translation>UTF-8</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="66"/>
        <source>US-ASCII</source>
        <translation>US-ASCII</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="74"/>
        <source>Error Fi&amp;le</source>
        <translation>Errore Fi&amp;le</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="92"/>
        <source>/tmp/errors.mmf</source>
        <translation>/tmp/errors.mmf</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="102"/>
        <source>&amp;Select error file</source>
        <translation>&amp;Selezionare il file di errore</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="141"/>
        <source>Proceed with selection of output file</source>
        <translation>Procedere con la selezione del file di output</translation>
    </message>
    <message>
        <location filename="../../export_dialog.ui" line="148"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <location filename="../../export_dialog.cc" line="42"/>
        <source>Select Error File</source>
        <translation>Seleziona il file di errore</translation>
    </message>
    <message>
        <location filename="../../export_dialog.cc" line="42"/>
        <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
        <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Testo (*.txt *.TXT);;Tutti i file (*)</translation>
    </message>
</context>
<context>
    <name>ImportDialog</name>
    <message>
        <location filename="../../import_dialog.ui" line="14"/>
        <source>Import MealMaster Recipes</source>
        <translation>Importa ricette di MealMaster</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="26"/>
        <source>Encodin&amp;g</source>
        <translation>Codifican&amp;do</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="46"/>
        <source>ISO-8859-1</source>
        <translation>ISO-8859-1</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="51"/>
        <source>ISO-8859-15</source>
        <translation>ISO-8859-15</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="56"/>
        <source>CP850</source>
        <translation>CP850</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="61"/>
        <source>UTF-8</source>
        <translation>UTF-8</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="66"/>
        <source>US-ASCII</source>
        <translation>US-ASCII</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="74"/>
        <source>Error Fi&amp;le</source>
        <translation>Errore Fi&amp;le</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="92"/>
        <source>/tmp/errors.mmf</source>
        <translation>/tmp/errors.mmf</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="102"/>
        <source>&amp;Select error file</source>
        <translation>&amp;Selezionare il file di errore</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="141"/>
        <source>Pr&amp;oceed with selection of recipes</source>
        <translation>Pr&amp;ocedi con la selezione delle ricette</translation>
    </message>
    <message>
        <location filename="../../import_dialog.ui" line="148"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <source>errors.mmf</source>
        <translation type="vanished">errors.mmf</translation>
    </message>
    <message>
        <location filename="../../import_dialog.cc" line="42"/>
        <source>Select Error File</source>
        <translation>Seleziona il file di errore</translation>
    </message>
    <message>
        <location filename="../../import_dialog.cc" line="42"/>
        <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
        <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Testo (*.txt *.TXT);;Tutti i file (*)</translation>
    </message>
</context>
<context>
    <name>IngredientModel</name>
    <message>
        <location filename="../../ingredient_model.cc" line="43"/>
        <source>amount</source>
        <translation>quantità</translation>
    </message>
    <message>
        <location filename="../../ingredient_model.cc" line="45"/>
        <source>unit</source>
        <translation>unità</translation>
    </message>
    <message>
        <location filename="../../ingredient_model.cc" line="47"/>
        <source>ingredient</source>
        <translation>ingrediente</translation>
    </message>
    <message>
        <location filename="../../ingredient_model.cc" line="76"/>
        <location filename="../../ingredient_model.cc" line="215"/>
        <source>&lt;Main&gt;</source>
        <translation>&lt;Principale&gt;</translation>
    </message>
</context>
<context>
    <name>InstructionsModel</name>
    <message>
        <location filename="../../instructions_model.cc" line="52"/>
        <location filename="../../instructions_model.cc" line="62"/>
        <source>&lt;Main&gt;</source>
        <translation>&lt;Principale&gt;</translation>
    </message>
    <message>
        <location filename="../../instructions_model.cc" line="78"/>
        <source>section</source>
        <translation>sezione</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../main_window.ui" line="14"/>
        <source>AnyMeal</source>
        <translation>AnyMeal</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="27"/>
        <source>&amp;Show all recipes</source>
        <translation>Mo&amp;stra tutte le ricette</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="34"/>
        <source>&amp;Title</source>
        <translation>&amp;Titolo</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="44"/>
        <source>Search for title text.</source>
        <translation>Cerca tramite il testo del titolo.</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="54"/>
        <location filename="../../main_window.ui" line="97"/>
        <source>w</source>
        <translation>con</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="64"/>
        <location filename="../../main_window.ui" line="110"/>
        <source>w/o</source>
        <translation>senza</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="74"/>
        <source>&amp;Category</source>
        <translation>&amp;Categoria</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="84"/>
        <source>Search for categories.</source>
        <translation>Cerca tramite categorie.</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="94"/>
        <source>Search for recipes with ingredient.</source>
        <translation>Cerca le ricette con l&apos;ingrediente.</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="107"/>
        <source>Search for recipes without ingredient.</source>
        <translation>Cerca le ricette senza l&apos;ingrediente.</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="120"/>
        <source>&amp;Ingredient</source>
        <translation>&amp;Ingrediente</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="130"/>
        <source>Specify the ingredient.</source>
        <translation>Specifica l&apos;ingrediente.</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="137"/>
        <source>&amp;Search</source>
        <translation>&amp;Cerca</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="201"/>
        <source>&amp;File</source>
        <translation>&amp;File</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="214"/>
        <source>&amp;Help</source>
        <translation>&amp;Aiuto</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="221"/>
        <source>Edit</source>
        <translation>Modifica</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="236"/>
        <source>Tool Bar</source>
        <translation>Barra degli strumenti</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="264"/>
        <source>&amp;Quit</source>
        <translation>&amp;Esci</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="267"/>
        <source>Exit application</source>
        <translation>Esci dall&apos;applicazione</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="270"/>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="279"/>
        <source>&amp;Import recipes</source>
        <translation>&amp;Importa le ricette</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="282"/>
        <source>Read MealMaster recipes from files</source>
        <translation>Leggi le ricette di MealMaster dai file</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="285"/>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="294"/>
        <source>Print p&amp;review</source>
        <translation>Antep&amp;rima di stampa</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="297"/>
        <source>Print preview of current recipe</source>
        <translation>Anteprima di stampa della ricetta corrente</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="300"/>
        <source>Ctrl+R</source>
        <translation>Ctrl+R</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="309"/>
        <source>&amp;Print recipe</source>
        <translation>Stam&amp;pa la ricetta</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="312"/>
        <source>Print current recipe</source>
        <translation>Stampa la ricetta attuale</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="315"/>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="324"/>
        <source>A&amp;bout AnyMeal</source>
        <translation>&amp;Riguardo a AnyMeal</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="327"/>
        <source>Ctrl+B</source>
        <translation>Ctrl+B</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="336"/>
        <source>&amp;Delete recipes</source>
        <translation>Cance&amp;lla le ricette</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="339"/>
        <source>Delete selected recipes</source>
        <translation>Cancella le ricette selezionate</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="342"/>
        <source>Del</source>
        <translation>Canc</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="351"/>
        <source>Exp&amp;ort recipes</source>
        <translation>Esp&amp;orta le ricette</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="354"/>
        <source>Write MealMaster recipes to file</source>
        <translation>Scrivi ricette MealMaster su file</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="357"/>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="366"/>
        <source>&amp;Edit Recipe</source>
        <translation>Modifica la ric&amp;etta</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="369"/>
        <source>Edit current recipe</source>
        <translation>Modifica la ricetta corrente</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="372"/>
        <source>Ctrl+E</source>
        <translation>Ctrl+E</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="381"/>
        <source>Collect &amp;Garbage</source>
        <translation>Racco&amp;gli la spazzatura</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="384"/>
        <source>Delete unused categories and ingredients</source>
        <translation>Elimina le categorie e gli ingredienti inutilizzati</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="387"/>
        <source>Ctrl+G</source>
        <translation>Ctrl+G</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="396"/>
        <source>Add &amp;to Category</source>
        <translation>Aggiungi alla ca&amp;tegoria</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="399"/>
        <source>Add selected recipes to a category</source>
        <translation>Aggiungi le ricette selezionate a una categoria</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="402"/>
        <source>Ctrl+T</source>
        <translation>Ctrl+T</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="411"/>
        <source>&amp;Remove from Category</source>
        <translation>&amp;Rimuovi dalla Categoria</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="414"/>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="423"/>
        <source>Open Co&amp;nverter Window</source>
        <translation>Aprire la finestra del co&amp;nvertitore</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="426"/>
        <source>Ctrl+U</source>
        <translation>Ctrl+U</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="453"/>
        <source>Ctrl+N</source>
        <translation>Ctrl+N</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="435"/>
        <source>Remove duplicates</source>
        <translation>Rimuovere i duplicati</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="438"/>
        <source>Remove duplicates in selected recipes</source>
        <translation>Rimuovere i duplicati nelle ricette selezionate</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="447"/>
        <source>New</source>
        <translation>Nuova</translation>
    </message>
    <message>
        <location filename="../../main_window.ui" line="450"/>
        <source>New recipe</source>
        <translation>Nuova ricetta</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="92"/>
        <source>Error Opening Database</source>
        <translation>Errore nell&apos;apertura del database</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="98"/>
        <source>Showing %1 recipes ...</source>
        <translation>Mostrando %1 ricette ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="108"/>
        <source>Import MealMaster Files</source>
        <translation>Importa File MealMaster</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="108"/>
        <location filename="../../main_window.cc" line="438"/>
        <source>MealMaster (*.mm *.MM *.mmf *.MMF);;Text (*.txt *.TXT);;All files (*)</source>
        <translation>MealMaster (*.mm *.MM *.mmf *.MMF);;Testo (*.txt *.TXT);;Tutti i file (*)</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="114"/>
        <source>Importing files ...</source>
        <translation>Importanto file ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="114"/>
        <location filename="../../main_window.cc" line="445"/>
        <location filename="../../main_window.cc" line="546"/>
        <source>Cancel</source>
        <translation>Annulla</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="123"/>
        <source>%1 imported and %2 failed ...</source>
        <translation>%1 importato e %2 fallito ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="137"/>
        <source>Rejected recipe: </source>
        <translation>Ricetta rifiutata: </translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="142"/>
        <location filename="../../main_window.cc" line="469"/>
        <location filename="../../main_window.cc" line="477"/>
        <source>Error writing to file </source>
        <translation>Errore nella scrittura del file </translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="163"/>
        <source>Recipes Imported</source>
        <translation>Ricette Importate</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="163"/>
        <source>%1 imported and %2 failed.</source>
        <translation>%1 importato e %2 fallito.</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="167"/>
        <source>Error While Importing</source>
        <translation>Errore durante l&apos;importazione</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="178"/>
        <source>Edit current recipe, a copy of the recipe, a new recipe, or cancel?</source>
        <translation>Modificare la ricetta corrente, una copia della ricetta, una nuova ricetta o annullare?</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="179"/>
        <source>&amp;Edit Current</source>
        <translation>Modifica corrent&amp;e</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="180"/>
        <source>Edit C&amp;opy</source>
        <translation>Modifica c&amp;opia</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="181"/>
        <source>Edit &amp;New</source>
        <translation>Modifica &amp;Nuovo</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="182"/>
        <source>&amp;Cancel</source>
        <translation>&amp;Annulla</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="250"/>
        <source>Error While Updating Recipe</source>
        <translation>Errore durante l&apos;aggiornamento della ricetta</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="275"/>
        <source>Error Adding Recipes to Category</source>
        <translation>Errore nell&apos;aggiungere ricette alla categoria</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="301"/>
        <source>Error Removing Recipes from Category</source>
        <translation>Errore nella rimozione delle ricette dalla categoria</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="320"/>
        <source>Error Collecting Garbage</source>
        <translation>Errore nella raccolta della spazzatura</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="329"/>
        <source>About AnyMeal %1</source>
        <translation>Riguardo a AnyMeal %1</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="374"/>
        <source>Error Filtering Recipes</source>
        <translation>Errore filtraggio delle ricette</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="388"/>
        <source>Error Resetting Selection</source>
        <translation>Errore ripristino della selezione</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="408"/>
        <source>Error fetching recipe</source>
        <translation>Errore nel recupero della ricetta</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="438"/>
        <source>Export MealMaster File</source>
        <translation>Esportare il File MealMaster</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="445"/>
        <source>Exporting recipes ...</source>
        <translation>Esportando le ricette ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="464"/>
        <source>Failed recipe: </source>
        <translation>Ricetta fallita:</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="480"/>
        <source>%1 exported and %2 failed ...</source>
        <translation>%1 esportato e %2 fallito ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="483"/>
        <source>Recipes Exported</source>
        <translation>Ricette esportate</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="483"/>
        <source>%1 exported and %2 failed.</source>
        <translation>%1 esportato e %2 fallito.</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="487"/>
        <source>Error While Exporting</source>
        <translation>Errore durante l&apos;esportazione</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="495"/>
        <source>Delete Recipes</source>
        <translation>Cancella le ricette</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="495"/>
        <source>Do you want to delete the selected recipes?</source>
        <translation>Vuoi cancellare le ricette selezionate?</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="514"/>
        <source>Error Deleting Recipes</source>
        <translation>Errore nell&apos;eliminazione delle ricette</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="546"/>
        <source>Detecting duplicates ...</source>
        <translation>Rilevamento duplicati ...</translation>
    </message>
    <message>
        <location filename="../../main_window.cc" line="549"/>
        <source>Found %1 duplicates ...</source>
        <translation>Trovati %1 duplicati ...</translation>
    </message>
</context>
<context>
    <name>recipe</name>
    <message>
        <location filename="../../html.cc" line="183"/>
        <source>Categories</source>
        <translation>Categorie</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="192"/>
        <source>Yield</source>
        <translation>Resa</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="196"/>
        <source>Ingredients</source>
        <translation>Ingredienti</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="199"/>
        <source>amount</source>
        <translation>quantità</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="200"/>
        <source>unit</source>
        <translation>unità</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="201"/>
        <source>ingredient</source>
        <translation>ingrediente</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="221"/>
        <source>Instructions</source>
        <translation>Istruzioni</translation>
    </message>
</context>
<context>
    <name>units</name>
    <message>
        <location filename="../../html.cc" line="60"/>
        <source>per serving</source>
        <translation>per porzione</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="61"/>
        <source>small</source>
        <translation>piccolo</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="62"/>
        <source>medium</source>
        <translation>medio</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="63"/>
        <source>large</source>
        <translation>grande</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="64"/>
        <source>can</source>
        <translation>lattina</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="65"/>
        <source>package</source>
        <translation>confezione</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="66"/>
        <source>pinch</source>
        <translation>pizzico</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="67"/>
        <source>drop</source>
        <translation>goccia</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="68"/>
        <source>dash</source>
        <translation>goccio</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="69"/>
        <source>carton</source>
        <translation>cartone</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="70"/>
        <source>bunch</source>
        <translation>grappolo</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="71"/>
        <source>slice</source>
        <translation>fetta</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="72"/>
        <source>each</source>
        <translation>cadauno</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="73"/>
        <location filename="../../html.cc" line="74"/>
        <source>teaspoon</source>
        <translation>cucchiaino</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="75"/>
        <location filename="../../html.cc" line="76"/>
        <source>tablespoon</source>
        <translation>cucchiaio</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="77"/>
        <source>fluid ounce</source>
        <translation>oncia fluida</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="78"/>
        <source>cup</source>
        <translation>tazza</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="79"/>
        <source>pint</source>
        <translation>pinta</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="80"/>
        <source>quart</source>
        <translation>quarto di gallone</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="81"/>
        <source>gallon</source>
        <translation>gallone</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="82"/>
        <source>ounce</source>
        <translation>oncia</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="83"/>
        <source>pound</source>
        <translation>libbra</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="84"/>
        <source>milliliter</source>
        <translation>millilitro</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="85"/>
        <source>cubic cm</source>
        <translation>cm cubi</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="86"/>
        <source>centiliter</source>
        <translation>centilitro</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="87"/>
        <source>deciliter</source>
        <translation>decilitro</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="88"/>
        <source>liter</source>
        <translation>litro</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="89"/>
        <source>milligram</source>
        <translation>milligrammo</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="90"/>
        <source>centigram</source>
        <translation>centigrammo</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="91"/>
        <source>decigram</source>
        <translation>decigrammo</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="92"/>
        <source>gram</source>
        <translation>grammo</translation>
    </message>
    <message>
        <location filename="../../html.cc" line="93"/>
        <source>kilogram</source>
        <translation>chilogrammo</translation>
    </message>
</context>
</TS>
